--
-- HrefUtils.hs
--
-- Copyright (c) 2003 Minero Aoki <aamine@loveruby.net>
--
-- This program is free software.
-- You can distribute/modify this program under the terms of
-- the GNU LGPL, Lesser General Public License version 2.
-- For details of the GNU LPGL, see the file "COPYING".
--

module Href.HrefUtils
    (encodePath, decodePath, rmPrefix, keysToPath,
     fullName, moduleName, functionName, myGetEnv, headChar)
where

import System
import System.IO
import Network.URI (escapeString, unEscapeString)
import Data.Char
import Data.List

import Href.TextUtils
import Href.Config

encodePath :: String -> String
encodePath cs = escapeString cs (\c -> isAlphaNum c || c == '_')

decodePath :: String -> String
decodePath cs = unEscapeString cs

rmPrefix :: String -> String
rmPrefix path = path \\ (hrefPrefix ++ "/")

keysToPath :: [String] -> String
keysToPath keys = join "/" (hrefPrefix : map (\k -> encodePath k) keys)

fullName :: String -> String
fullName path = m ++ "." ++ f
                where (m,f) = splitPath path

functionName :: String -> String
functionName path = f where (m,f) = splitPath path

moduleName :: String -> String
moduleName path = m where (m,f) = splitPath path

splitPath :: String -> (String,String)
splitPath path = split2 '/' $ decodePath $ rmPrefix path

myGetEnv :: String -> IO String
myGetEnv key =
    catch (getEnv key)
          (\e -> do hPutStrLn stderr $ "environment variable not set: " ++ key
                    exitWith $ ExitFailure 1)

headChar :: String -> Char
headChar []     = ' '
headChar (x:xs) = x
